<?php
/**************************************************************************\
* eGroupWare                                                               *
* http://www.egroupware.org                                                *
* --------------------------------------------                             *
*  This program is free software; you can redistribute it and/or modify it *
*  under the terms of the GNU General Public License as published by the   *
*  Free Software Foundation; either version 2 of the License, or (at your  *
*  option) any later version.                                              *
\**************************************************************************/

/**
 * Specialization of the BaseFactory class.
 * This class is used to instantiate classes by
 * the workflow module (not by processes). You
 * cannot access this class directly, but requests
 * to the Factory frontend class in 'unsecured mode'
 * will be forwarded to this class.
 *
 * @package Factory
 * @license http://www.gnu.org/copyleft/gpl.html GPL
 * @author Pedro Eugênio Rocha - pedro.eugenio.rocha@gmail.com
 */
final class WorkflowFactory extends BaseFactory {


	/**
	 * @var boolean $_instantiated Attribute that stores whether this
	 *		class was instantiated or not. This is used to limit the
	 * 		instantiation of this class.
	 * @access private
	 * @static
	 */
	private static $_instantiated = false;


	/**
	 * Construct the class. This function will inform which classes
	 * you will be able to instantiate and where to find it.
	 * This function implements a kind of singleton design pattern too.
	 * @access public
	 */
	public function __construct() {

		/* don't let the user to instantiate this class more than once. */
		if (self::$_instantiated)
			throw new Exception("You can't instantiate this class again.");

		/* registering allowed classes */
		$this->registerFileInfo('WorkflowObjects', 'class.WorkflowObjects.inc.php', 'inc');
		$this->registerFileInfo('WorkflowWatcher', 'class.WorkflowWatcher.inc.php', 'inc');
		$this->registerFileInfo('WorkflowLDAP', 'class.WorkflowLDAP.inc.php', 'inc');
		$this->registerFileInfo('WorkflowSecurity', 'class.WorkflowSecurity.inc.php', 'inc');
		$this->registerFileInfo('ResourcesRedirector', 'class.ResourcesRedirector.inc.php', 'inc');
		$this->registerFileInfo('TemplateServer', 'class.TemplateServer.inc.php', 'inc');
		$this->registerFileInfo('CachedLDAP', 'class.CachedLDAP.inc.php', 'inc');
		$this->registerFileInfo('BrowserInfo', 'class.BrowserInfo.inc.php', 'inc');

		$this->registerFileInfo('workflow_smarty', 'class.workflow_smarty.inc.php', 'inc');
		$this->registerFileInfo('workflow_acl', 'class.workflow_acl.inc.php', 'inc');
		$this->registerFileInfo('workflow_processmanager', 'class.workflow_processmanager.inc.php', 'inc');

		$this->registerFileInfo('bo_participants', 'class.bo_participants.inc.php', 'inc');

		/* registering egw class example */
		$this->registerFileInfo('phpgw', 'class.phpgw.inc.php', '', EGW_INC_ROOT);
		$this->registerFileInfo('db', 'class.db.inc.php', '', EGW_INC_ROOT);
		$this->registerFileInfo('accounts', 'class.accounts.inc.php', '', EGW_INC_ROOT);


		/**
		 * TODO - This is a veeery big workaround to maintain compatibility with
		 * processes that uses the old not-static factory. So, we made this wrapper
		 * (adapter) that just calls the new and cute static factory class in the
		 * right way. It should be removed as soon as possible.
		*/
		$this->registerFileInfo('ProcessWrapperFactory', 'ProcessWrapperFactory.php', 'lib/factory/');


		/* ok. no more instances of this class.. */
		self::$_instantiated = true;
	}
}

?>
